Ansible Changes By Release
==========================

## 0.4 - March 25, 2014

- List available issue queries
- Display tickets in oneline condensed format
- List tickets by query ID
- Allow user reference by UID, firstname, or firstname and lastname

## Earlier releases

- See git log
